@@ -13,7 +13,9 @@ if PYQT_VERSIONS == "PyQt5":
         QPolygon,
         QPolygonF,
         QFont,
-        QLinearGradient
+        QLinearGradient,
+        QFontMetricsF,
+        QCloseEvent,
     )
 
 if PYQT_VERSIONS == "PyQt6":
@@ -29,7 +31,9 @@ if PYQT_VERSIONS == "PyQt6":
         QPolygon,
         QPolygonF,
         QFont,
-        QLinearGradient
+        QLinearGradient,
+        QFontMetricsF,
+        QCloseEvent
     )
 
 if PYQT_VERSIONS == "PySide2":
@@ -45,7 +49,9 @@ if PYQT_VERSIONS == "PySide2":
         QPolygon,
         QPolygonF,
         QFont,
-        QLinearGradient
+        QLinearGradient,
+        QFontMetricsF,
+        QCloseEvent
     )
 
 
@@ -62,5 +68,7 @@ if PYQT_VERSIONS == "PySide6":
         QPolygon,
         QPolygonF,
         QFont,
-        QLinearGradient
+        QLinearGradient,
+        QFontMetricsF,
+        QCloseEvent
     )
\ No newline at end of file
